@@ -1,11 +1,5 @@
-# calculate scaled data matrix
-# @param X a matrix
-# @param scale_vars a vector of variable names or FALSE
-# @param scale_pars a matrix of scaling parameters or FALSE or NULL
-# @param meth
-# @export
 
-scale_matrix <- function(X, scale_vars, scale_pars, meth) {
+scale_matrix <- function(X, scale_vars, scale_pars, models) {
   Xsc <- X
   if (!is.null(X)) {
     Xsub <- X[, apply(X, 2, function(x)(any(!is.na(x)))), drop = FALSE]
@@ -18,16 +12,16 @@ scale_matrix <- function(X, scale_vars, scale_pars, meth) {
                              dimnames = list(c("scale", "center"),
                                              scale_vars[scale_vars %in% colnames(Xsub)]))
         for (k in scale_vars[scale_vars %in% colnames(Xsub)]) {
-          usecenter <- if (!k %in% names(meth)) {
+          usecenter <- if (!k %in% names(models)) {
             TRUE
           } else {
-            !meth[k] %in% c("lognorm", "gamma", "beta")
+            !models[k] %in% c("lognorm", "gamma", "beta", 'glmm_gamma', 'glmm_poisson')
           }
 
-          usescale <- if (!k %in% names(meth)) {
+          usescale <- if (!k %in% names(models)) {
             TRUE
           } else {
-            !meth[k] %in% c("gamma", "beta")
+            !models[k] %in% c("gamma", "beta", 'glmm_gamma', 'glmm_poisson')
           }
 
           xsc <- scale(X[, k], center = usecenter, scale = usescale)
@@ -51,9 +45,11 @@ scale_matrix <- function(X, scale_vars, scale_pars, meth) {
 }
 
 
-# function for scaling
-# @export
-get_scaling <- function(Mlist, scale_pars, meth, data) {
+
+
+
+
+get_scaling <- function(Mlist, scale_pars, models, data) {
   varnams <- unique(unlist(strsplit(colnames(model.matrix(Mlist$fixed2, data)),
                                     "[:|*]")))
   scale_pars_new <- if (!is.null(Mlist$scale_vars))
@@ -63,10 +59,10 @@ get_scaling <- function(Mlist, scale_pars, meth, data) {
                            varnams))
 
 
-  scaled_dat <- sapply(Mlist[c("Xc", "Xtrafo", "Xl", "Z")], scale_matrix,
+  scaled_dat <- sapply(Mlist[c("Xc", "Xtrafo", "Xl", "Z", "Xltrafo")], scale_matrix,
                        scale_vars = Mlist$scale_vars,
                        scale_pars = scale_pars,
-                       meth = meth, simplify = FALSE)
+                       models = models, simplify = FALSE)
 
 
   scale_pars <- do.call(cbind, lapply(scaled_dat, "[[", 2))
@@ -93,7 +89,7 @@ get_scaling <- function(Mlist, scale_pars, meth, data) {
   if (any(Mlist$trafos$fct == paste0(Mlist$trafos$var, "^2"))) {
     sqrs <- which(Mlist$trafos$fct == paste0(Mlist$trafos$var, "^2"))
     xvars <- Mlist$trafos$var[sqrs]
-    xsqr <- Mlist$trafos$Xc_var[sqrs]
+    xsqr <- Mlist$trafos$X_var[sqrs]
     scale_pars_new[, xsqr] <- scale_pars_new[, xvars]^2
     scale_pars_new["center", xsqr] <- -scale_pars_new["center", xsqr]
   }
@@ -101,3 +97,20 @@ get_scaling <- function(Mlist, scale_pars, meth, data) {
   return(list(scaled_matrices = sapply(scaled_dat, "[[", 1, simplify = FALSE),
               scale_pars = scale_pars_new))
 }
+
+
+
+
+# Function to find the names of columns in the model matrix that involve
+# continuous covariates (and hence may need to be scaled) - only main effects
+find_continuous_main <- function(fixed, DF) {
+  # remove left side of formula
+  fmla <- as.formula(sub("[[:print:]]*\\~", "~",
+                         deparse(fixed, width.cutoff = 500)))
+
+  # check which variables involved are continuous
+  is_continuous <- !sapply(model.frame(fmla, DF), is.factor)
+  # Note: does this have to be so complicated? can't I just take the columns of DF???
+
+  names(is_continuous)[is_continuous]
+}
